import java.util.*;
import java.io.*;

/**
Quick script to list all the Currency types the JVM knows about.
*/
public class ListCurrencies {

	private static String currStr = "code: %s, symbol: %s, fdigits: %d, name: %s\n";

    public static void main(String[] args) throws Exception {
		// ensure we get a unicode capable output stream
		PrintWriter consoleOut =
			new PrintWriter(new OutputStreamWriter(System.out, "UTF-8"));

		// Currency doesn't implement Comparable, so we're sorting on the ISO string code
		Set<Currency> curs = Currency.getAvailableCurrencies();
		SortedSet<Currency> sortedcurs = new TreeSet<Currency>(
			(Currency c1, Currency c2) -> c1.getCurrencyCode().compareTo(c2.getCurrencyCode())
		);
		sortedcurs.addAll(curs);

		for (Currency c : sortedcurs) {
			consoleOut.printf(currStr,
				c.getCurrencyCode(),
				c.getSymbol(),
				c.getDefaultFractionDigits(),
				c.getDisplayName()
			);
		}

		consoleOut.println("Count: "+curs.size());
		consoleOut.close();
	}
}
